@@ -9,7 +9,6 @@ from typing import Any, List, Optional, Sequence, Text, Tuple, Union, overload
 
 import pygame
 import pygame_menu
-from pygame.key import key_code
 from pygame.locals import *
 
 from primaryschool.dirs import *
@@ -19,7 +18,7 @@ from primaryschool.resource import (default_font, default_font_path,
                                     get_sys_font_by_lang_code)
 from primaryschool.subjects import *
 from primaryschool.subjects._abc_ import GameBase
-from primaryschool.subjects._common_.keycode import KeyCode
+from primaryschool.subjects._common_.keycode import PsKeyCode
 
 
 class ShootingWave():
@@ -145,16 +144,18 @@ class TargetSurface():
     def get_h(self):
         return self.size[1]
 
-    def get_default_bg_points(self, tip_height=50):
-        return [
-            (self.get_x(), self.get_y()),
-            (self.get_x() + self.get_w(), self.get_y()),
-            (self.get_x() + self.get_w(), self.get_y() + self.get_h()),
-            (
-                self.get_x() + self.get_w() / 2,
-                self.get_y() + self.get_h() + tip_height),
-            (self.get_x(), self.get_y() + self.get_h())
-        ]
+    def get_default_bg_points(self, tip_height=55):
+        return \
+            [
+                (self.get_x(), self.get_y()),
+                (self.get_x() + self.get_w(), self.get_y()),
+                (self.get_x() + self.get_w(), self.get_y() + self.get_h()),
+                (
+                    self.get_x() + self.get_w() / 2,
+                    self.get_y() + self.get_h() + tip_height
+                ),
+                (self.get_x(), self.get_y() + self.get_h())
+            ]
 
     def draw_bg(self):
         pygame.draw.polygon(
@@ -165,7 +166,12 @@ class TargetSurface():
     def calc_dest(self, _add):
         return
 
-    def move(self, _add=(1, 1), rel=True, use_func=False):
+    def move(
+        self, 
+        _add=(1, 1), 
+        rel=True, 
+        use_func=False):
+        
         if use_func:
             self.dest = self.calc_dest(_add)
         elif rel:
@@ -268,7 +274,7 @@ class TargetsManager():
         self.intercept_keycode = intercept_keycode
         self.target_count = 20
 
-    def set_intercept_keycode(self, keycode):
+    def set_intercept_keycode(self, Pskeycode):
         self.intercept_keycode = keycode
 
     def get_targets(self, d: int = 0, count=20):
@@ -312,6 +318,7 @@ class TargetsManager():
     def get_target_surfaces(self):
         _targets = self.get_targets(self.shtbase.difficulty_index)
         self.set_target_count(len(_targets))
+
         return [
             TargetSurface(self.shtbase, self, t[0:-1], t[-1])
             for t in _targets
@@ -503,14 +510,19 @@ class DefenseSurface():
         return self.emitter_color
 
     def get_center(self):
-        return [self.ps.w_width_of_2, self.ps.w_height - self.h / 2]
+        return \
+            [
+                self.ps.w_width_of_2,
+                self.ps.w_height - self.h / 2
+            ]
 
     def draw_emitter(self):
         self.emitter_color = self.set_emitter_color() \
             if self.shtbase.targets_manager is None \
             else self.shtbase.targets_manager.laser_color
-        pygame.draw.circle(self.ps.surface, self.emitter_color,
-                           self.center, self.emitter_radius)
+        pygame.draw.circle(
+            self.ps.surface, self.emitter_color,
+            self.center, self.emitter_radius)
 
     def blit(self):
         self.surface.fill(self.color)
@@ -531,7 +543,7 @@ class InfoSurface():
         self.font_size = 25
         self.font = get_default_font(self.font_size)
 
-        self.score_font_size = 66
+        self.score_font_size = 55
         self.score_font = get_default_font(self.score_font_size)
 
         self.datetime_diff_font_size = 50
@@ -596,9 +608,12 @@ class InfoSurface():
         return self._pass
 
     def get_greeting(self):
+        _player_name = self.shtbase.get_player_name()
         return \
-            _('Success!') if self._pass else \
-            _('Practice makes perfect, keep trying!')
+        (
+            _('Success! Dear %s, you are so awesome!') if self._pass else \
+            _('Dear %s, practice makes perfect, keep trying!')
+        )%_player_name
 
     def get_score_str(self):
         return _('Score: ') + str(self.score)
@@ -658,7 +673,7 @@ class InfoSurface():
             self.get_datetime_diff_surface_dest())
 
 
-class ShootingBase(GameBase, KeyCode):
+class ShootingBase(GameBase, PsKeyCode):
     def __init__(self, ps, font_lang_code=None):
         assert hasattr(self, 'name_t')
         assert hasattr(self, 'difficulties')
@@ -674,6 +689,7 @@ class ShootingBase(GameBase, KeyCode):
         self.running = True
         self.FPS = self.ps.FPS
         self.clock = self.ps.clock
+        self.player_name = self.ps.player_name
         self._load = False
 
         self.font_lang_code = font_lang_code or sys_lang_code
@@ -705,6 +721,12 @@ class ShootingBase(GameBase, KeyCode):
         self.target_count = 0
         self.print_game_info()
 
+    def get_player_name(self):
+        return self.player_name
+    
+    def set_player_name(self,name):
+        self.player_name = self.ps.player_name = name
+
     def set_input(self, content=''):
         self._input = content
 
